import { __decorate, __metadata } from "tslib";
import { CanvasConfig, ContextService } from '@antv/g';
import { inject, singleton } from 'mana-syringe';
import { isString } from '@antv/util';
import { createSVGElement } from '@antv/g-plugin-svg-renderer';

var SVGContextService =
/** @class */
function () {
  function SVGContextService() {}

  SVGContextService.prototype.init = function () {
    var container = this.canvasConfig.container; // create container

    this.$container = isString(container) ? document.getElementById(container) : container;

    if (this.$container) {
      if (!this.$container.style.position) {
        this.$container.style.position = 'relative';
      }

      var $namespace = createSVGElement('svg');
      $namespace.setAttribute('width', "" + this.canvasConfig.width);
      $namespace.setAttribute('height', "" + this.canvasConfig.height);
      this.$container.appendChild($namespace);
      this.$namespace = $namespace;
    }

    var dpr = window.devicePixelRatio || 1;
    dpr = dpr >= 1 ? Math.ceil(dpr) : 1;
    this.dpr = dpr;
  }; // @ts-ignore


  SVGContextService.prototype.getDomElement = function () {
    return this.$namespace;
  };

  SVGContextService.prototype.getContext = function () {
    return this.$namespace;
  };

  SVGContextService.prototype.getDPR = function () {
    return this.dpr;
  };

  SVGContextService.prototype.getBoundingClientRect = function () {
    var _a;

    return (_a = this.$namespace) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
  };

  SVGContextService.prototype.destroy = function () {
    // destroy context
    if (this.$container && this.$namespace && this.$namespace.parentNode) {
      this.$container.removeChild(this.$namespace);
    }
  };

  SVGContextService.prototype.resize = function (width, height) {
    if (this.$namespace) {
      this.$namespace.setAttribute('width', "" + width);
      this.$namespace.setAttribute('height', "" + height);
    }
  };

  SVGContextService.prototype.applyCursorStyle = function (cursor) {
    if (this.$container) {
      this.$container.style.cursor = cursor;
    }
  };

  __decorate([inject(CanvasConfig), __metadata("design:type", Object)], SVGContextService.prototype, "canvasConfig", void 0);

  SVGContextService = __decorate([singleton({
    token: ContextService
  })], SVGContextService);
  return SVGContextService;
}();

export { SVGContextService };