"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SVGContextService = void 0;

var _tslib = require("tslib");

var _g = require("@antv/g");

var _manaSyringe = require("mana-syringe");

var _util = require("@antv/util");

var _gPluginSvgRenderer = require("@antv/g-plugin-svg-renderer");

var SVGContextService =
/** @class */
function () {
  function SVGContextService() {}

  SVGContextService.prototype.init = function () {
    var container = this.canvasConfig.container; // create container

    this.$container = (0, _util.isString)(container) ? document.getElementById(container) : container;

    if (this.$container) {
      if (!this.$container.style.position) {
        this.$container.style.position = 'relative';
      }

      var $namespace = (0, _gPluginSvgRenderer.createSVGElement)('svg');
      $namespace.setAttribute('width', "" + this.canvasConfig.width);
      $namespace.setAttribute('height', "" + this.canvasConfig.height);
      this.$container.appendChild($namespace);
      this.$namespace = $namespace;
    }

    var dpr = window.devicePixelRatio || 1;
    dpr = dpr >= 1 ? Math.ceil(dpr) : 1;
    this.dpr = dpr;
  }; // @ts-ignore


  SVGContextService.prototype.getDomElement = function () {
    return this.$namespace;
  };

  SVGContextService.prototype.getContext = function () {
    return this.$namespace;
  };

  SVGContextService.prototype.getDPR = function () {
    return this.dpr;
  };

  SVGContextService.prototype.getBoundingClientRect = function () {
    var _a;

    return (_a = this.$namespace) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
  };

  SVGContextService.prototype.destroy = function () {
    // destroy context
    if (this.$container && this.$namespace && this.$namespace.parentNode) {
      this.$container.removeChild(this.$namespace);
    }
  };

  SVGContextService.prototype.resize = function (width, height) {
    if (this.$namespace) {
      this.$namespace.setAttribute('width', "" + width);
      this.$namespace.setAttribute('height', "" + height);
    }
  };

  SVGContextService.prototype.applyCursorStyle = function (cursor) {
    if (this.$container) {
      this.$container.style.cursor = cursor;
    }
  };

  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_g.CanvasConfig), (0, _tslib.__metadata)("design:type", Object)], SVGContextService.prototype, "canvasConfig", void 0);
  SVGContextService = (0, _tslib.__decorate)([(0, _manaSyringe.singleton)({
    token: _g.ContextService
  })], SVGContextService);
  return SVGContextService;
}();

exports.SVGContextService = SVGContextService;